pub enum ResolveDirection {
IntoFuture,
IntoPast,
}Expand description
If the desired day cannot be resolved, should we find the next day into the future that satisfies the requirement, or the day into the past.
Variants
IntoFuture
Resolve by looking forward into the future for the next valid day
IntoPast
Resolve by looking back into the past for the next valid day